@@ -12,12 +12,13 @@ require([
 
     Terminal.applyAddon(fit);
 
-    function GitSync(baseUrl, repo, branch, depth, path) {
+    function GitSync(baseUrl, repo, branch, depth, targetpath, path) {
         // Class that talks to the API backend & emits events as appropriate
         this.baseUrl = baseUrl;
         this.repo = repo;
         this.branch = branch;
         this.depth = depth;
+        this.targetpath = targetpath;
         this.redirectUrl = baseUrl + path;
 
         this.callbacks = {};
@@ -43,11 +44,14 @@ require([
         // Start git pulling handled by SyncHandler, declared in handlers.py
         var syncUrlParams = {
             repo: this.repo,
-            branch: this.branch
+            targetpath: this.targetpath
         }
         if (typeof this.depth !== 'undefined' && this.depth != undefined) {
             syncUrlParams['depth'] = this.depth;
         }
+        if (typeof this.branch !== 'undefined' && this.branch != undefined) {
+            syncUrlParams['branch'] = this.branch;
+        }
         var syncUrl = this.baseUrl + 'git-pull/api?' + $.param(syncUrlParams);
 
         this.eventSource = new EventSource(syncUrl);
@@ -90,7 +94,7 @@ require([
         }
         this.visible = visible;
         if (visible) {
-            // See https://github.com/data-8/nbgitpuller/pull/46 on why this is here.
+            // See https://github.com/jupyterhub/nbgitpuller/pull/46 on why this is here.
             if (!this.term.element) {
                 this.term.open($(this.termSelector)[0]);
             }
@@ -129,6 +133,7 @@ require([
         utils.get_body_data('repo'),
         utils.get_body_data('branch'),
         utils.get_body_data('depth'),
+        utils.get_body_data('targetpath'),
         utils.get_body_data('path')
     );
 
